@@ -1,9 +1,9 @@
 # __author__ = 'sadaqatullah'
 
 # __version__ = '0.1.6.9'
-__version__ = '0.0.0.3'
+__version__ = '0.0.0.5'
 
 from bSecure.base import (
     authenticate, set_order, create_order, update_order, single_sign_on_set_values, single_sign_on,
-    checkout_button_image, sso_login_button_image, sso_get_customer_profile
+    checkout_button_image, sso_login_button_image, sso_get_customer_profile, status_order
 )
